@@ -21,12 +21,12 @@
 
 install_version <- function(package, version = NULL,
                             dependencies = NA,
-                            upgrade = c("ask", "always", "never"),
+                            upgrade = c("default", "ask", "always", "never"),
                             force = FALSE,
                             quiet = FALSE,
                             build = FALSE, build_opts = c("--no-resave-data", "--no-manual", "--no-build-vignettes"),
                             repos = getOption("repos"),
-                            type = getOption("pkgType"),
+                            type = "source",
                             ...) {
 
   url <- download_version_url(package, version, repos, type)
